@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "trigger.h"
 
@@ -139,7 +127,7 @@ Palapeli::Trigger::Trigger(const QByteArray& serialization)
 	if (sections[1] != "NoModifier")
 	{
 		const QList<QByteArray> modifierStrings = sections[1].split('|');
-		foreach (const QByteArray& modifierString, modifierStrings)
+		for (const QByteArray& modifierString : modifierStrings)
 		{
 			Qt::KeyboardModifier modifier = tParserData->m_modifierStrings.key(modifierString, Qt::NoModifier);
 			if (modifier == Qt::NoModifier)
@@ -166,7 +154,7 @@ QByteArray Palapeli::Trigger::serialized() const
 	if (!isValid())
 		return QByteArray();
 	const QByteArray actionString = tParserData->actionString(m_wheelDirection, m_button);
-	QByteArray modifierString = tParserData->modifierString(m_modifiers, '|');
+	QByteArray modifierString = tParserData->modifierString(m_modifiers, QLatin1Char('|'));
 	if (modifierString.isEmpty())
 		modifierString = "NoModifier";
 	return actionString + QByteArray(1, ';') + modifierString;
@@ -175,11 +163,11 @@ QByteArray Palapeli::Trigger::serialized() const
 QString Palapeli::Trigger::toString() const
 {
 	const QString actionString = tPrinterData->actionString(m_wheelDirection, m_button);
-	const QString modifierString = tPrinterData->modifierString(m_modifiers, '+');
+	const QString modifierString = tPrinterData->modifierString(m_modifiers, QLatin1Char('+'));
 	if (modifierString.isEmpty())
 		return actionString;
 	else
-		return modifierString + QChar('+') + actionString;
+		return modifierString + QLatin1Char('+') + actionString;
 }
 
 Qt::KeyboardModifiers Palapeli::Trigger::modifiers() const
